You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2008/12/25 10:57:30 UTC

svn commit: r729412 - in /activemq/camel/trunk/components: camel-jms/src/main/java/org/apache/camel/component/jms/ camel-mail/src/main/java/org/apache/camel/component/mail/ camel-mail/src/test/java/org/apache/camel/component/mail/ camel-mina/src/main/j...

Author: davsclaus
Date: Thu Dec 25 01:57:28 2008
New Revision: 729412

URL: http://svn.apache.org/viewvc?rev=729412&view=rev
Log:
fixed spelling

Modified:
    activemq/camel/trunk/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsBinding.java
    activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailComponent.java
    activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailEndpoint.java
    activemq/camel/trunk/components/camel-mail/src/test/java/org/apache/camel/component/mail/InvalidConfigurationTest.java
    activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaConsumer.java
    activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaPayloadHolder.java
    activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaProducer.java
    activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderFailedException.java
    activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderService.java
    activemq/camel/trunk/components/camel-stream/src/main/java/org/apache/camel/component/stream/StreamProducer.java
    activemq/camel/trunk/components/camel-xmpp/src/main/java/org/apache/camel/component/xmpp/XmppEndpoint.java

Modified: activemq/camel/trunk/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsBinding.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsBinding.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailComponent.java (original)
+++ activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailComponent.java Thu Dec 25 01:57:28 2008
@@ -69,7 +69,7 @@
     }
 
     private void configureAdditionalJavaMailProperties(MailConfiguration config, Map parameters) {
-        // we can not remove while iterating, as we will get a modification exception
+        // we cannot remove while iterating, as we will get a modification exception
         Set toRemove = new HashSet();
 
         for (Object key : parameters.keySet()) {

Modified: activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailEndpoint.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailEndpoint.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailEndpoint.java (original)
+++ activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailEndpoint.java Thu Dec 25 01:57:28 2008
@@ -66,7 +66,7 @@
     public Consumer createConsumer(Processor processor) throws Exception {
         if (configuration.getProtocol().startsWith("smtp")) {
             throw new IllegalArgumentException("Protocol " + configuration.getProtocol()
-                + " can not be used for a MailConsumer. Please use another protocol such as pop3 or imap.");
+                + " cannot be used for a MailConsumer. Please use another protocol such as pop3 or imap.");
         }
 
         JavaMailSenderImpl sender = configuration.createJavaMailSender();

Modified: activemq/camel/trunk/components/camel-mail/src/test/java/org/apache/camel/component/mail/InvalidConfigurationTest.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-mail/src/test/java/org/apache/camel/component/mail/InvalidConfigurationTest.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-mail/src/test/java/org/apache/camel/component/mail/InvalidConfigurationTest.java (original)
+++ activemq/camel/trunk/components/camel-mail/src/test/java/org/apache/camel/component/mail/InvalidConfigurationTest.java Thu Dec 25 01:57:28 2008
@@ -31,7 +31,7 @@
         PollingConsumer consumer = endpoint.createPollingConsumer();
         try {
             consumer.start();
-            fail("Should have thrown NoSuchProviderException as stmp protocol can not be used for consuming mails");
+            fail("Should have thrown NoSuchProviderException as stmp protocol cannot be used for consuming mails");
         } catch (IllegalArgumentException e) {
             // expected
         }
@@ -42,7 +42,7 @@
         PollingConsumer consumer = endpoint.createPollingConsumer();
         try {
             consumer.start();
-            fail("Should have thrown NoSuchProviderException as stmp protocol can not be used for consuming mails");
+            fail("Should have thrown NoSuchProviderException as stmp protocol cannot be used for consuming mails");
         } catch (IllegalArgumentException e) {
             // expected
         }

Modified: activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaConsumer.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaConsumer.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaConsumer.java (original)
+++ activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaConsumer.java Thu Dec 25 01:57:28 2008
@@ -121,7 +121,7 @@
                 if (body == null) {
                     // must close session if no data to write otherwise client will never receive a response
                     // and wait forever (if not timing out)
-                    LOG.warn("Can not write body since its null, closing session: " + exchange);
+                    LOG.warn("Cannot write body since its null, closing session: " + exchange);
                     session.close();
                 } else {
                     // we got a response to write

Modified: activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaPayloadHolder.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaPayloadHolder.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaPayloadHolder.java (original)
+++ activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaPayloadHolder.java Thu Dec 25 01:57:28 2008
@@ -116,7 +116,7 @@
         if (object instanceof Serializable) {
             return object;
         } else {
-            LOG.warn(type + " containig object " + object + " can not be serialized, it will be excluded by the MinaPayloadHolder");
+            LOG.warn(type + " containig object " + object + " cannot be serialized, it will be excluded by the MinaPayloadHolder");
             return null;
         }
     }
@@ -132,7 +132,7 @@
                 result.put(entry.getKey(), entry.getValue());
             } else {
                 LOG.warn(type + " containing object " + entry.getValue() + " of key " + entry.getKey()
-                         + " can not be serialized, it will be excluded by the MinaPayloadHolder");
+                         + " cannot be serialized, it will be excluded by the MinaPayloadHolder");
             }
         }
 

Modified: activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaProducer.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaProducer.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaProducer.java (original)
+++ activemq/camel/trunk/components/camel-mina/src/main/java/org/apache/camel/component/mina/MinaProducer.java Thu Dec 25 01:57:28 2008
@@ -134,7 +134,7 @@
 
         if (connector instanceof SocketConnector) {
             // Change the worker timeout to 0 second to make the I/O thread quit soon when there's no connection to manage.
-            // Default worker timeout is 60 sec and therefore the client using MinaProducer can not terminate the JVM
+            // Default worker timeout is 60 sec and therefore the client using MinaProducer cannot terminate the JVM
             // asap but must wait for the timeout to happend, so to speed this up we set the timeout to 0.
             if (LOG.isDebugEnabled()) {
                 LOG.debug("Setting SocketConnector WorkerTimeout=0 to force MINA stopping its resources faster");

Modified: activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderFailedException.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderFailedException.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderFailedException.java (original)
+++ activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderFailedException.java Thu Dec 25 01:57:28 2008
@@ -17,7 +17,7 @@
 package org.apache.camel.spring.processor.onexception;
 
 /**
- * Exception thrown if the order can not be processed
+ * Exception thrown if the order cannot be processed
  */
 public class OrderFailedException extends Exception {
 

Modified: activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderService.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderService.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-stream/src/main/java/org/apache/camel/component/stream/StreamProducer.java (original)
+++ activemq/camel/trunk/components/camel-stream/src/main/java/org/apache/camel/component/stream/StreamProducer.java Thu Dec 25 01:57:28 2008
@@ -134,7 +134,7 @@
             outputStream.write((byte[])body);
         } else {
             throw new CamelExchangeException("The body is neither a String or byte array. "
-                + "Can not write body to output stream", exchange);
+                + "Cannot write body to output stream", exchange);
         }
     }
 

Modified: activemq/camel/trunk/components/camel-xmpp/src/main/java/org/apache/camel/component/xmpp/XmppEndpoint.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-xmpp/src/main/java/org/apache/camel/component/xmpp/XmppEndpoint.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-xmpp/src/main/java/org/apache/camel/component/xmpp/XmppEndpoint.java (original)
+++ activemq/camel/trunk/components/camel-xmpp/src/main/java/org/apache/camel/component/xmpp/XmppEndpoint.java Thu Dec 25 01:57:28 2008
@@ -258,7 +258,7 @@
         XMPPConnection conn = getConnection();
         Iterator<String> iterator = MultiUserChat.getServiceNames(conn).iterator();
         if (!iterator.hasNext()) {
-            throw new CamelException("Can not find Multi User Chat service");
+            throw new CamelException("Cannot find Multi User Chat service");
         }
         String chatServer = iterator.next();
         if (LOG.isInfoEnabled()) {
--- activemq/camel/trunk/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsBinding.java (original)
+++ activemq/camel/trunk/components/camel-jms/src/main/java/org/apache/camel/component/jms/JmsBinding.java Thu Dec 25 01:57:28 2008
@@ -248,7 +248,7 @@
             if (value != null) {
                 jmsMessage.setObjectProperty(key, value);
             } else if (LOG.isDebugEnabled()) {
                 // okay the value is not a primitive or string so we can not sent it over the wire
                 LOG.debug("Ignoring non primitive header: " + headerName + " of class: "
                     + headerValue.getClass().getName() + " with value: " + headerValue);
             }
@@ -316,7 +316,7 @@
                 return result;
             } catch (JMSException e) {
                 // if MapMessage creation failed then fall back to Object Message
-                LOG.warn("Can not populate MapMessage will fall back to ObjectMessage, cause by: " + e.getMessage());
+                LOG.warn("Cannot populate MapMessage will fall back to ObjectMessage, cause by: " + e.getMessage());
             }
         }
         if (body instanceof String) {
@@ -248,7 +248,7 @@
                 jmsMessage.setObjectProperty(key, value);
             } else if (LOG.isDebugEnabled()) {
-                // okay the value is not a primitive or string so we can not sent it over the wire
+                // okay the value is not a primitive or string so we cannot sent it over the wire
                 LOG.debug("Ignoring non primitive header: " + headerName + " of class: "
                     + headerValue.getClass().getName() + " with value: " + headerValue);

Modified: activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailComponent.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-mail/src/main/java/org/apache/camel/component/mail/MailComponent.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderService.java (original)
+++ activemq/camel/trunk/components/camel-spring/src/test/java/org/apache/camel/spring/processor/onexception/OrderService.java Thu Dec 25 01:57:28 2008
@@ -34,13 +34,13 @@
      * @param payload the in payload
      * @param out the out headers
      * @return the out payload
      * @throws OrderFailedException is thrown if the order can not be processed
      */
     public Object handleOrder(@Headers Map in, @Body String payload, @OutHeaders Map out)
         throws OrderFailedException {
         out.put("customerid", in.get("customerid"));
         if ("Order: kaboom".equals(payload)) {
-            throw new OrderFailedException("Can not order: kaboom");
+            throw new OrderFailedException("Cannot order: kaboom");
         } else {
             out.put("orderid", "123");
             return "Order OK";
@@ -34,13 +34,13 @@
      * @param out the out headers
      * @return the out payload
-     * @throws OrderFailedException is thrown if the order can not be processed
+     * @throws OrderFailedException is thrown if the order cannot be processed
      */
     public Object handleOrder(@Headers Map in, @Body String payload, @OutHeaders Map out)

Modified: activemq/camel/trunk/components/camel-stream/src/main/java/org/apache/camel/component/stream/StreamProducer.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-stream/src/main/java/org/apache/camel/component/stream/StreamProducer.java?rev=729412&r1=729411&r2=729412&view=diff
==============================================================================